gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r21114 - in gnunet/src: dht include


From: gnunet
Subject: [GNUnet-SVN] r21114 - in gnunet/src: dht include
Date: Mon, 23 Apr 2012 17:52:13 +0200

Author: grothoff
Date: 2012-04-23 17:52:13 +0200 (Mon, 23 Apr 2012)
New Revision: 21114

Modified:
   gnunet/src/dht/dht.h
   gnunet/src/include/gnunet_service_lib.h
Log:
-fix

Modified: gnunet/src/dht/dht.h
===================================================================
--- gnunet/src/dht/dht.h        2012-04-23 15:51:05 UTC (rev 21113)
+++ gnunet/src/dht/dht.h        2012-04-23 15:52:13 UTC (rev 21114)
@@ -196,7 +196,7 @@
 
 
 /**
- * Message to monitor put requests going through peer, DHT service --> clients.
+ * Message to monitor put requests going through peer, DHT service -> clients.
  */
 struct GNUNET_DHT_MonitorPutMessage
 {
@@ -249,7 +249,7 @@
 
 
 /**
- * Message to request monitoring messages, clients --> DHT service.
+ * Message to request monitoring messages, clients -> DHT service.
  */
 struct GNUNET_DHT_MonitorStartMessage
 {
@@ -336,7 +336,7 @@
 };
 
 /**
- * Message to monitor get results going through peer, DHT service --> clients.
+ * Message to monitor get results going through peer, DHT service -> clients.
  */
 struct GNUNET_DHT_MonitorGetRespMessage
 {

Modified: gnunet/src/include/gnunet_service_lib.h
===================================================================
--- gnunet/src/include/gnunet_service_lib.h     2012-04-23 15:51:05 UTC (rev 
21113)
+++ gnunet/src/include/gnunet_service_lib.h     2012-04-23 15:52:13 UTC (rev 
21114)
@@ -43,7 +43,7 @@
  * Get the list of addresses that a server for the given service
  * should bind to.
  *
  * @param serviceName name of the service
  * @param cfg configuration (which specifies the addresses)
  * @param addrs set (call by reference) to an array of pointers to the
  *              addresses the server should bind to and listen on; the
@@ -60,7 +60,7 @@
  *              set to NULL).
  */
 int
-GNUNET_SERVICE_get_server_addresses (const char *serviceName,
+GNUNET_SERVICE_get_server_addresses (const char *service_name,
                                      const struct GNUNET_CONFIGURATION_Handle
                                      *cfg, struct sockaddr ***addrs,
                                      socklen_t ** addr_lens);
@@ -43,7 +43,7 @@
  * should bind to.
  *
- * @param serviceName name of the service
+ * @param service_name name of the service
  * @param cfg configuration (which specifies the addresses)
  * @param addrs set (call by reference) to an array of pointers to the




reply via email to

[Prev in Thread] Current Thread [Next in Thread]